% Plot Script for LCI Paper

colorVec = tumColors;

colormapExtended = reshape(struct2array(colorVec.Extended), [3,10])';
colormapExtended = [colormapExtended;colormapExtended];

file = 'SI1_ScalableLCI_Results';


[materialMix, labels, ~] = xlsread(file, 'MaterialMix');

labels = strrep(labels, ' [kg]','');
labels = strrep(labels, ' Mass','');
labels = strrep(labels, '*','');


vehicleLabels = categorical(labels(3:end,1));
vehicleLabels = categorical(vehicleLabels, labels(3:end,1));
materialLabels = labels(1,4:end);

temp1 = materialMix(:,3:end)./materialMix(:,2);
temp2 = temp1;

temp1(temp1<=0.05) = 0;

temp2(temp2>0.05) = 0;

rest = sum(temp2,2);

emptyCol = find(all(temp1==0));

temp1(:,emptyCol) = [];
materialLabels(:,emptyCol) = [];

%% Figure relative material mix
idxCol = find(any(materialMix./materialMix(:,2)>=0.05));

temp3 = materialMix(:,idxCol(idxCol>2))./materialMix(:,2);

figure

h1 = bar(vehicleLabels, [1-sum(temp3,2) temp3].*100, 'Stacked', 'FaceColor','flat', 'linestyle','none');


% legend(['Other' labels(1,idxCol(2:end)+1)], 'Location', 'Eastoutside')
l1 = fliplegend(['Other' labels(2,idxCol(2:end)+1)]);
set(l1, 'Location', 'EastOutside', 'Box', 'off')

set(gca, 'YGrid', 'on', 'YMinorTick', 'on')

ylim([0, 100])
ylabel('Percentage of Vehicle Weight')

text([1:size(temp3, 1)], ones(1,5)*100, strcat('\Sigma', {' '}, num2str(materialMix(:,2),'%.0f'), {' '}, 'kg'),'HorizontalAlignment','center','VerticalAlignment','bottom');


for i = 1:length(h1)
    h1(i).CData = ones(length(h1(i).CData),1)*colormapExtended(i,:);
    if i == 10
        i=1;
    end
end



style = hgexport('readstyle','MDPI', 'YMinorTick', 'on');
hgexport(gcf,'temp_dummy',style,'applystyle', true);
set(gcf,'PaperSize',[15+2*0.636 6+2*0.636]); %set the paper size to what you want  
print(gcf,'MaterialMixRelative','-dpdf', '-fillpage') % then print it

%% Figure relative material mix
idxCol = find(any(materialMix./materialMix(:,2)>=0.05));

temp3 = materialMix(:,idxCol(idxCol>2));

figure

h1 = bar(vehicleLabels, [1-sum(temp3,2) temp3], 'Stacked', 'FaceColor','flat', 'linestyle','none');


% legend(['Other' labels(1,idxCol(2:end)+1)], 'Location', 'Eastoutside')
l1 = fliplegend(['Other' labels(2,idxCol(2:end)+1)]);
set(l1, 'Location', 'EastOutside', 'Box', 'off')

set(gca, 'YGrid', 'on', 'YMinorTick', 'on')

ylim([0, 12000])
ylabel('Vehicle Weight in kg')

text([1:size(temp3, 1)], ones(1,5)*12000, strcat('\Sigma', {' '}, num2str(materialMix(:,2),'%.0f'), {' '}, 'kg'),'HorizontalAlignment','center','VerticalAlignment','bottom');


for i = 1:length(h1)
    h1(i).CData = ones(length(h1(i).CData),1)*colormapExtended(i,:);
    if i == 10
        i=1;
    end
end



style = hgexport('readstyle','MDPI', 'YMinorTick', 'on');
hgexport(gcf,'temp_dummy',style,'applystyle', true);
set(gcf,'PaperSize',[15+2*0.636 6+2*0.636]); %set the paper size to what you want  
print(gcf,'MaterialMix','-dpdf', '-fillpage') % then print it


%% %% Figure energy consumption cradle-to-gate
[ctgEnergy, ctgLabelsRaw, ~] = xlsread(file, 'Cradle-to-Gate');
ctgLabelsRaw = strrep(ctgLabelsRaw, '*','');

%%

figure
h2 = bar(vehicleLabels, ctgEnergy(1:16,13:17)/1000, 'Stacked', 'FaceColor','flat', 'linestyle','none');

ctgLabels = categorical(ctgLabelsRaw(3:18,2));
ctgLabels = categorical(ctgLabels, ctgLabelsRaw(3:18,2));
l2 = fliplegend(ctgLabels);
set(l2, 'Location', 'EastOutside', 'Box', 'off')

set(gca, 'TickLength', [0 .01], 'YGrid', 'on', 'YLim', [0 2000], 'YMinorTick', 'on')

% text([1:size(vehicleLabels, 1)], ctgEnergy(17,13:17)/1000, strcat('\Sigma', num2str(ctgEnergy(17,13:17)'/1000,'%.1f')),'HorizontalAlignment','center','VerticalAlignment','bottom')
text([1:size(vehicleLabels, 1)], ones(1,5)*2000, strcat('\Sigma', {' '}, num2str(ctgEnergy(17,13:17)'/1000,'%.1f')),'HorizontalAlignment','center','VerticalAlignment','bottom')

ylabel('Cradle-to-Gate Energy in MWh')



% l = legend(ctgLabels, 'Location', 'Eastoutside');

for i = 1:length(h2)

    h2(i).CData = ones(length(h2(i).CData),1)*colormapExtended(i,:);

end

style = hgexport('readstyle','MDPI');
hgexport(gcf,'temp_dummy',style,'applystyle', true);
set(gcf,'PaperSize',[15+2*0.636 6+2*0.636]); %set the paper size to what you want  
print(gcf,'CtG_Energy','-dpdf', '-fillpage') % then print it

%% %% Figure GWP cradle-to-gate
figure
h3 = bar(vehicleLabels, ctgEnergy(1:16,18:22)/1000, 'Stacked', 'FaceColor','flat', 'linestyle','none');

l3 = fliplegend(ctgLabels);
set(l3, 'Location', 'EastOutside', 'Box', 'off')

set(gca, 'TickLength', [0 .01], 'YGrid', 'on', 'YLim', [0 200], 'YMinorTick', 'on')

text([1:size(vehicleLabels, 1)], ones(1,5)*200, strcat('\Sigma', {' '}, num2str(ctgEnergy(17,18:22)'/1000,'%.1f')),'HorizontalAlignment','center','VerticalAlignment','bottom')
% text([1:size(vehicleLabels, 1)], ctgEnergy(17,18:22)/1000, strcat('\Sigma', num2str(ctgEnergy(17,18:22)'/1000,'%.1f')),'HorizontalAlignment','center','VerticalAlignment','bottom')

ylabel('Cradle-to-Gate GWP in tCO_{2}-eq.')

% ctgLabels = categorical(ctgLabelsRaw(3:18,2));
% ctgLabels = categorical(ctgLabelsRaw(3:18,2));

% l = legend(ctgLabels, 'Location', 'Eastoutside');

for i = 1:length(h3)

    h3(i).CData = ones(length(h3(i).CData),1)*colormapExtended(i,:);
end


style = hgexport('readstyle','MDPI');
hgexport(gcf,'temp_dummy',style,'applystyle', true);
set(gcf,'PaperSize',[15+2*0.636 6+2*0.636]); %set the paper size to what you want  
print(gcf,'CtG_GWP','-dpdf', '-fillpage') % then print it

% addpath('C:\FTM_MatlabToolbar\FTMMatlabShortcuts\'),figureTUMColors

%% Comparison

[errorData, errorLabelsRaw, ~] = xlsread(file, 'Comparison');

errorLabels = categorical(errorLabelsRaw(22:27,1));
errorLabels = categorical(errorLabels, errorLabelsRaw(22:27,1));


figure

h4 = bar(errorLabels, [errorData(20:25,2) errorData(20:25,4)].*100, 'grouped', 'FaceColor','flat', 'linestyle','none');

for i = 1:length(h4)
    h4(i).CData = ones(length(h4(i).CData),1)*colorVec.Colormap.Primary(i,:);
end

set(gca, 'TickLength', [0 .01], 'YGrid', 'on', 'XTickLabelRotation', 0, 'YLim', [-10 10], 'YMinorTick', 'on')

ylabel('Absolute Error in %')

legend({'\Delta Gaines', '\Delta Altenburg'}, 'Location', 'best')

style = hgexport('readstyle','MDPI');
hgexport(gcf,'temp_dummy',style,'applystyle', true);
set(gcf,'PaperSize',[15+2*0.636 4+2*0.636]); %set the paper size to what you want  
% print(gcf,'comparison','-dpdf', '-fillpage') % then print it

%%
figure

hold on
h1 = plot(1:length(errorLabels), -errorData(20:25,2).*100, 'linestyle','none', 'Marker', 'x', 'Linewidth', 1.66, 'MarkerSize', 10, 'Color', colorVec.Colormap.Primary(1,:));
h2 = plot(1:length(errorLabels), -errorData(20:25,4).*100, 'linestyle','none', 'Marker', '+', 'Linewidth', 1.66, 'MarkerSize', 10,'Color', colorVec.Colormap.Primary(2,:));

line([0 7], [0 0],'LineStyle','-', 'Color', 'black')

box on
xlim([0.5 6.5])
ylim([-10 10])

set(gca, 'XTickLabel', errorLabels, 'YMinorTick', 'on')
ylabel('Absolute Deviation in %')

l1 = legend({'\Delta Gaines', '\Delta Altenburg'}, 'Location', 'best');
set(l1, 'Box','off')

style = hgexport('readstyle','MDPI');
hgexport(gcf,'temp_dummy',style,'applystyle', true);
set(gcf,'PaperSize',[15+2*0.636 4+2*0.636]); %set the paper size to what you want  
print(gcf,'comparison','-dpdf', '-fillpage') % then print it

%% Plot absoult values for comparison
figure

hold on

h1 = plot((1:length(errorLabels))-0.1, errorData(20:25,1).*100, 'linestyle','none', 'Marker', 'x', 'Linewidth', 2, 'MarkerSize', 5, 'Color', colorVec.secondary.Grey);
h2 = plot((1:length(errorLabels))+0.1, errorData(20:25,3).*100, 'linestyle','none', 'Marker', 'x', 'Linewidth', 2, 'MarkerSize', 5,'Color', colorVec.primary.Black);
h3 = plot(1:length(errorLabels), errorData(20:25,5).*100, 'linestyle','none', 'Marker', '+', 'Linewidth', 2, 'MarkerSize', 5,'Color', colorVec.Colormap.Primary(1,:));

% line([0 7], [0 0],'LineStyle','-', 'Color', 'black')

text([1:size(errorLabels, 1)], ones(1,size(errorLabels, 1))*100, strcat('\sigma', {'='}, num2str(std(errorData(20:25,1:2:5)'.*100)','%.2f'), '%'),'HorizontalAlignment','center','VerticalAlignment','bottom')

box on
xlim([0.5 6.5])
ylim([0 100])

set(gca, 'XTickLabel', errorLabels, 'YMinorTick', 'on')
ylabel('Percentage of Vehicle Weight')

l1 = legend({'Gaines', 'Altenburg', 'LCI'}, 'Location', 'best');
set(l1, 'Box','off')

style = hgexport('readstyle','MDPI');
hgexport(gcf,'temp_dummy',style,'applystyle', true);
set(gcf,'PaperSize',[15+2*0.636 4+2*0.636]); %set the paper size to what you want  
print(gcf,'comparison','-dpdf', '-fillpage') % then print it


